==> eigenpy-2.2.1-py38hffdd584_0.tar.bz2: Library/lib/cmake/eigenpy/eigenpyConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set("eigenpy_INCLUDE_DIRS" "D:/bld/eigenpy_1585342176298/_h_env/Library/include")
set("EIGENPY_INCLUDE_DIRS" "D:/bld/eigenpy_1585342176298/_h_env/Library/include")
set("eigenpy_DOXYGENDOCDIR" "${PACKAGE_PREFIX_DIR}/share/doc/eigenpy/doxygen-html")
set("EIGENPY_DOXYGENDOCDIR" "${PACKAGE_PREFIX_DIR}/share/doc/eigenpy/doxygen-html")
set("eigenpy_DEPENDENCIES" "")
set("eigenpy_PKG_CONFIG_DEPENDENCIES" "eigen3 >= 3.0.5")

include(CMakeFindDependencyMacro)


IF(COMMAND ADD_REQUIRED_DEPENDENCY)
  FOREACH(pkgcfg_dep ${eigenpy_PKG_CONFIG_DEPENDENCIES})
    ADD_REQUIRED_DEPENDENCY(${pkgcfg_dep})
  ENDFOREACH()
ENDIF(COMMAND ADD_REQUIRED_DEPENDENCY)

include("${CMAKE_CURRENT_LIST_DIR}/eigenpyTargets.cmake")
check_required_components("eigenpy")

==> eigenpy-2.2.2-py38hffdd584_0.tar.bz2: Library/lib/cmake/eigenpy/eigenpyConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set("eigenpy_INCLUDE_DIRS" "D:/bld/eigenpy_1585730482012/_h_env/Library/include")
set("EIGENPY_INCLUDE_DIRS" "D:/bld/eigenpy_1585730482012/_h_env/Library/include")
set("eigenpy_DOXYGENDOCDIR" "${PACKAGE_PREFIX_DIR}/share/doc/eigenpy/doxygen-html")
set("EIGENPY_DOXYGENDOCDIR" "${PACKAGE_PREFIX_DIR}/share/doc/eigenpy/doxygen-html")
set("eigenpy_DEPENDENCIES" "")
set("eigenpy_PKG_CONFIG_DEPENDENCIES" "eigen3 >= 3.0.5")
set("eigenpy_LIBRARIES" "abs_lib_eigenpy.lib-NOTFOUND;D:/bld/eigenpy_1585730482012/_h_env/Library/lib/boost_python38.lib")
set("EIGENPY_LIBRARIES" "abs_lib_eigenpy.lib-NOTFOUND;D:/bld/eigenpy_1585730482012/_h_env/Library/lib/boost_python38.lib")

include(CMakeFindDependencyMacro)


IF(COMMAND ADD_REQUIRED_DEPENDENCY)
  FOREACH(pkgcfg_dep ${eigenpy_PKG_CONFIG_DEPENDENCIES})
    ADD_REQUIRED_DEPENDENCY(${pkgcfg_dep})
  ENDFOREACH()
ENDIF(COMMAND ADD_REQUIRED_DEPENDENCY)

include("${CMAKE_CURRENT_LIST_DIR}/eigenpyTargets.cmake")
check_required_components("eigenpy")
